# Authors

This list is sorted by the number of commits per contributor in _descending_ order.

Avatar|Contributor|Contributions
:-:|---|:-:
<img class='float-left rounded-1' src='https://avatars1.githubusercontent.com/u/15666417?v=4' width='36' height='36' alt='@JarryShaw'>|[@JarryShaw](https://github.com/JarryShaw)|391

---

Auto-generated by [gaocegege/maintainer](https://github.com/gaocegege/maintainer) on 2019-10-24.
